package rulettasztal;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;
import java.util.Random;

/**
 * @author Daniel "3ICE" Berezvai
 */
public class RouletteTable {

  Random rnd;
  List<IRoulettePlayer> players;
  Queue<BetItem> betItems;
  Integer lastNumber;

  public RouletteTable(Random rnd) {
    this.rnd = rnd;
    players = new ArrayList<>(1);
    betItems = new LinkedList<>();
  }

  void join(IRoulettePlayer rp) {
    players.add(rp);
  }

  void betsPlease() {
    for (IRoulettePlayer p : players) {
      betItems.add(new BetItem(p, p.nextBetNumber(), p.nextBetCredit()));
    }
  }

  void giveCreditToAll(Integer credit) {
    for (IRoulettePlayer p : players) {
      p.giveCredit(credit);
    }
  }

  Integer spin() {
    lastNumber = rnd.nextInt(37);
    return lastNumber;
  }

  void payWinners() {
    for (BetItem b : betItems) {
      if (b.number == lastNumber) {
        b.owner.giveCredit(b.credit * 36);
      }
    }
    betItems.clear();
  }

  List<Integer> getPlayersCredits() {
    List<Integer> l = new ArrayList<>(players.size());
    for (IRoulettePlayer p : players) {
      l.add(p.getCredit());
    }
    return l;
  }

  List<Integer> getPlayersBets() {
    List<Integer> l = new ArrayList<>(betItems.size());
    for (BetItem b : betItems) {
      l.add(b.credit);
    }
    return l;
  }

  List<Integer> getPlayersNumbers() {
    List<Integer> l = new ArrayList<>(betItems.size());
    for (BetItem b : betItems) {
      l.add(b.number);
    }
    return l;
  }
}
